# In Memory Backend
The In Memory Backend is a Redis replacement written in python.

It is comparatively slow but if you don't want to have a Redis server, you can use it.

To use the In Memory Backend you only have to disable the `redis` Module.